@@ -53,14 +53,18 @@ RGB565 = 1  # 16-bit color displays
 GS4_HMSB = 2  # Unimplemented!
 MHMSB = 3  # Single bit displays like the Sharp Memory
 
+
 class MHMSBFormat:
     """MHMSBFormat"""
+
     @staticmethod
     def set_pixel(framebuf, x, y, color):
         """Set a given pixel to a color."""
         index = (y * framebuf.stride + x) // 8
         offset = 7 - x & 0x07
-        framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) | ((color != 0) << offset)
+        framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) | (
+            (color != 0) << offset
+        )
 
     @staticmethod
     def get_pixel(framebuf, x, y):
@@ -84,21 +88,26 @@ class MHMSBFormat:
         """Draw a rectangle at the given location, size and color. The ``fill_rect`` method draws
         both the outline and interior."""
         # pylint: disable=too-many-arguments
-        for _x in range(x, x+width):
+        for _x in range(x, x + width):
             offset = 7 - _x & 0x07
-            for _y in range(y, y+height):
+            for _y in range(y, y + height):
                 index = (_y * framebuf.stride + _x) // 8
-                framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) \
-                                      | ((color != 0) << offset)
+                framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) | (
+                    (color != 0) << offset
+                )
+
 
 class MVLSBFormat:
     """MVLSBFormat"""
+
     @staticmethod
     def set_pixel(framebuf, x, y, color):
         """Set a given pixel to a color."""
         index = (y >> 3) * framebuf.stride + x
         offset = y & 0x07
-        framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) | ((color != 0) << offset)
+        framebuf.buf[index] = (framebuf.buf[index] & ~(0x01 << offset)) | (
+            (color != 0) << offset
+        )
 
     @staticmethod
     def get_pixel(framebuf, x, y):
@@ -126,11 +135,13 @@ class MVLSBFormat:
             index = (y >> 3) * framebuf.stride + x
             offset = y & 0x07
             for w_w in range(width):
-                framebuf.buf[index + w_w] = (framebuf.buf[index + w_w] & ~(0x01 << offset)) |\
-                                           ((color != 0) << offset)
+                framebuf.buf[index + w_w] = (
+                    framebuf.buf[index + w_w] & ~(0x01 << offset)
+                ) | ((color != 0) << offset)
             y += 1
             height -= 1
 
+
 class FrameBuffer:
     """FrameBuffer object.
 
@@ -149,6 +160,7 @@ class FrameBuffer:
                    ``buf`` size must accommodate an increased step size.
 
     """
+
     def __init__(self, buf, width, height, buf_format=MVLSB, stride=None):
         # pylint: disable=too-many-arguments
         self.buf = buf
@@ -163,7 +175,7 @@ class FrameBuffer:
         elif buf_format == MHMSB:
             self.format = MHMSBFormat()
         else:
-            raise ValueError('invalid format')
+            raise ValueError("invalid format")
         self._rotation = 0
 
     @property
@@ -258,20 +270,26 @@ class FrameBuffer:
             y = self.height - y - height
 
         # pylint: disable=too-many-boolean-expressions
-        if width < 1 or height < 1 or (x + width) <= 0 or (y + height) <= 0 or \
-                y >= self.height or x >= self.width:
+        if (
+            width < 1
+            or height < 1
+            or (x + width) <= 0
+            or (y + height) <= 0
+            or y >= self.height
+            or x >= self.width
+        ):
             return
-        x_end = min(self.width-1, x + width-1)
-        y_end = min(self.height-1, y + height-1)
+        x_end = min(self.width - 1, x + width - 1)
+        y_end = min(self.height - 1, y + height - 1)
         x = max(x, 0)
         y = max(y, 0)
         if fill:
-            self.format.fill_rect(self, x, y, x_end-x+1, y_end-y+1, color)
+            self.format.fill_rect(self, x, y, x_end - x + 1, y_end - y + 1, color)
         else:
-            self.format.fill_rect(self, x, y, x_end-x+1, 1, color)
-            self.format.fill_rect(self, x, y, 1, y_end-y+1, color)
-            self.format.fill_rect(self, x, y_end, x_end-x+1, 1, color)
-            self.format.fill_rect(self, x_end, y, 1, y_end-y+1, color)
+            self.format.fill_rect(self, x, y, x_end - x + 1, 1, color)
+            self.format.fill_rect(self, x, y, 1, y_end - y + 1, color)
+            self.format.fill_rect(self, x, y_end, x_end - x + 1, 1, color)
+            self.format.fill_rect(self, x_end, y, 1, y_end - y + 1, color)
 
     def line(self, x_0, y_0, x_1, y_1, color):
         # pylint: disable=too-many-arguments
@@ -327,50 +345,53 @@ class FrameBuffer:
             x = shift_x
             while x != xend:
                 self.format.set_pixel(
-                    self, x, y, self.format.get_pixel(self, x - delta_x, y - delta_y))
+                    self, x, y, self.format.get_pixel(self, x - delta_x, y - delta_y)
+                )
                 x += dt_x
             y += dt_y
 
     # pylint: disable=too-many-arguments
-    def text(self, string, x, y, color, *,
-             font_name="font5x8.bin", size=1):
+    def text(self, string, x, y, color, *, font_name="font5x8.bin", size=1):
         """Place text on the screen in variables sizes. Breaks on \n to next line.
 
         Does not break on line going off screen.
         """
-        for chunk in string.split('\n'):
+        for chunk in string.split("\n"):
             if not self._font or self._font.font_name != font_name:
                 # load the font!
                 self._font = BitmapFont()
             w = self._font.font_width
             for i, char in enumerate(chunk):
-                self._font.draw_char(char,
-                                     x + (i * (w + 1))*size,
-                                     y, self, color, size=size)
-            y += self._font.font_height*size
+                self._font.draw_char(
+                    char, x + (i * (w + 1)) * size, y, self, color, size=size
+                )
+            y += self._font.font_height * size
+
     # pylint: enable=too-many-arguments
 
-
-
     def image(self, img):
         """Set buffer to value of Python Imaging Library image.  The image should
         be in 1 bit mode and a size equal to the display size."""
-        if img.mode != '1':
-            raise ValueError('Image must be in mode 1.')
+        if img.mode != "1":
+            raise ValueError("Image must be in mode 1.")
         imwidth, imheight = img.size
         if imwidth != self.width or imheight != self.height:
-            raise ValueError('Image must be same dimensions as display ({0}x{1}).' \
-                .format(self.width, self.height))
+            raise ValueError(
+                "Image must be same dimensions as display ({0}x{1}).".format(
+                    self.width, self.height
+                )
+            )
         # Grab all the pixels from the image, faster than getpixel.
         pixels = img.load()
         # Clear buffer
         for i in range(len(self.buf)):
             self.buf[i] = 0
         # Iterate through the pixels
-        for x in range(self.width):       # yes this double loop is slow,
+        for x in range(self.width):  # yes this double loop is slow,
             for y in range(self.height):  #  but these displays are small!
                 if pixels[(x, y)]:
-                    self.pixel(x, y, 1)   # only write if pixel is true
+                    self.pixel(x, y, 1)  # only write if pixel is true
+
 
 # MicroPython basic bitmap font renderer.
 # Author: Tony DiCola
@@ -379,7 +400,8 @@ class BitmapFont:
     """A helper class to read binary font tiles and 'seek' through them as a
     file to display in a framebuffer. We use file access so we dont waste 1KB
     of RAM on a font!"""
-    def __init__(self, font_name='font5x8.bin'):
+
+    def __init__(self, font_name="font5x8.bin"):
         # Specify the drawing area width and height, and the pixel function to
         # call when drawing pixels (should take an x and y param at least).
         # Optionally specify font_name to override the font file to use (default
@@ -395,8 +417,8 @@ class BitmapFont:
         # Open the font file and grab the character width and height values.
         # Note that only fonts up to 8 pixels tall are currently supported.
         try:
-            self._font = open(self.font_name, 'rb')
-            self.font_width, self.font_height = struct.unpack('BB', self._font.read(2))
+            self._font = open(self.font_name, "rb")
+            self.font_width, self.font_height = struct.unpack("BB", self._font.read(2))
             # simple font file validation check based on expected file size
             if 2 + 256 * self.font_width != os.stat(font_name)[6]:
                 raise RuntimeError("Invalid font file: " + font_name)
@@ -421,11 +443,13 @@ class BitmapFont:
         """cleanup on exit"""
         self.deinit()
 
-    def draw_char(self, char, x, y, framebuffer, color, size=1): # pylint: disable=too-many-arguments
+    def draw_char(
+        self, char, x, y, framebuffer, color, size=1
+    ):  # pylint: disable=too-many-arguments
         """Draw one character at position (x,y) to a framebuffer in a given color"""
         size = max(size, 1)
         # Don't draw the character if it will be clipped off the visible area.
-        #if x < -self.font_width or x >= framebuffer.width or \
+        # if x < -self.font_width or x >= framebuffer.width or \
         #   y < -self.font_height or y >= framebuffer.height:
         #    return
         # Go through each column of the character.
@@ -433,14 +457,16 @@ class BitmapFont:
             # Grab the byte for the current column of font data.
             self._font.seek(2 + (ord(char) * self.font_width) + char_x)
             try:
-                line = struct.unpack('B', self._font.read(1))[0]
+                line = struct.unpack("B", self._font.read(1))[0]
             except RuntimeError:
-                continue # maybe character isnt there? go to next
+                continue  # maybe character isnt there? go to next
             # Go through each row in the column byte.
             for char_y in range(self.font_height):
                 # Draw a pixel for each bit that's flipped on.
                 if (line >> char_y) & 0x1:
-                    framebuffer.fill_rect(x + char_x*size, y + char_y*size, size, size, color)
+                    framebuffer.fill_rect(
+                        x + char_x * size, y + char_y * size, size, size, color
+                    )
 
     def width(self, text):
         """Return the pixel width of the specified text message."""
@@ -449,4 +475,3 @@ class BitmapFont:
 
 class FrameBuffer1(FrameBuffer):  # pylint: disable=abstract-method
     """FrameBuffer1 object. Inherits from FrameBuffer."""
-    pass
